##################################
### mIRCShitlist.tcl           ###
### Version 1.2                ###
### By Wcc                     ###
### http://www.dawgtcl.com:81/ ###
### http://dawg.dynu.com       ###
### EFnet #|DAWG|Tcl           ###
##################################

############################################################################
### Copyright  2000 - 2002 |DAWG| Scripting Group. All rights reserved. ###
############################################################################

#####################################################################
## This script imports Polaris-based mIRC shitlists into eggdrop's ##
## global ban list.                                                ##
#####################################################################

##############
## COMMANDS ##
###########################################################################
## DCC ## .shitlist [-r] <shitlist file> [access-level] (Can be changed) ##
######### Imports an mIRC shitlist into the bot's banlist. Polaris       ##
######### shitlists use access-level 40, so if you are using Polaris,    ##
######### you don't need to specify an access-level. Use the -r option   ##
######### to remove all bans that are in a shitlist file instead of      ##
######### adding them.                                                   ##
###########################################################################

##########################################################
## Just load the script, edit the settings, and rehash. ##
##########################################################

#######################################
# Set the ban reason to be used here. #
#######################################

set mircshitlist_setting(reason) "Shitlisted"

###################################################
# Set the flag required to import shitlists here. #
###################################################

set mircshitlist_setting(flag) "+n"

###################################
# Enable use of bold in DCC chat? #
###################################

set mircshitlist_setting(bold) 1

################################################
# Prefix "MIRCSHITLIST:" in DCC chat messages? #
################################################

set mircshitlist_setting(MIRCSHITLIST:) 1

####################
# Code begins here #
####################

if {![string match 1.6.* $version]} { putlog "\002MIRCSHITLIST:\002 \002WARNING:\002 This script is intended to run on eggdrop 1.6.x or later." }
if {[info tclversion] < 8.2} { putlog "\002MIRCSHITLIST:\002 \002WARNING:\002 This script is intended to run on Tcl Version 8.2 or later." }

bind dcc $mircshitlist_setting(flag) shitlist mircshitlist_import

proc mircshitlist_dopre {} {
	global mircshitlist_setting
	if {!$mircshitlist_setting(MIRCSHITLIST:)} { return "" }
	if {!$mircshitlist_setting(bold)} { return "MIRCSHITLIST: " }
	return "\002MIRCSHITLIST:\002 "
}
proc mircshitlist_import {hand idx text} {
	global mircshitlist_setting
	set arg1 [lindex [split $text] 0]
	set arg2 [lindex [split $text] 1]
	set arg3 [lindex [split $text] 2]
	if {$text == ""} { putdcc $idx "[mircshitlist_dopre]Usage: .shitlist \[-r\] <shitlist file> \[access-level\]" ; return }
	if {$arg2 == ""} { set open $arg1 } { set open $arg2 }
	if {[catch {open $open r} list]} { putdcc $idx "[mircshitlist_dopre]Could not open $open." ; return }
	set lev [expr {($arg3 != "")?"$arg3":"40"}]
	set imported 0
	set removed 0
	set data [split [read $list] \n]
	close $list
	foreach line $data {
		if {![string match ${lev}:* [set line [join $line]]]} { continue }
		if {[string match -r $arg1]} {
			if {![isban [set line [string range $line [expr [string first : $line] + 1] end]]]} { continue }
			incr removed
			killban $line
		} {
			if {[isban [set line [string range $line [expr [string first : $line] + 1] end]]]} { continue }
			incr imported
			lappend mircshitlist_data $line
			newban $line mIRCShitlist $mircshitlist_setting(reason) 0
		}
	}
	putdcc $idx "[mircshitlist_dopre]Imported $imported bans and removed $removed bans from $arg2."
	if {[info exists mircshitlist_data] && $imported != 0} {
		putdcc $idx "[mircshitlist_dopre]Now kicking shitlisted users from all channels."
		mircshitlist_kick $idx $mircshitlist_data
	}
}
proc mircshitlist_kick {idx hosts} {
	global mircshitlist_setting
	set kicked 0
	foreach host $hosts {
		foreach chan [channels] {
			if {![botisop $chan]} { continue }
			foreach u [chanlist $chan] {
				if {![string match [string tolower $host] [string tolower $u![getchanhost $u]]]} { continue }
				incr kicked
				pushmode $chan +b $host
				putserv "KICK $chan $u :$mircshitlist_setting(reason)"
			}
		}
	}
	if {$kicked != 0} { putdcc $idx "[mircshitlist_dopre]Kicked $kicked users." }
}
putlog "\002MIRCSHITLIST:\002 mIRCShitlist.tcl Version 1.2 by Wcc is loaded."